from tkinter import *
import time
import datetime
import RPi.GPIO as GPIO
import smbus
import sys
import math

SENSOR_ADDRESS=0X08
bus=smbus.SMBus(1)
time.sleep(1)

c1=-3.690447415e-03
c2=11.71105411e-04
c3=-45.21970288e-07


pHNeutral=227
pHAcid=123

kLow = 40 
kHigh = 68
RES2= 820.0
ECREF=200.0

class Board:
	def __init__(self, canvas, temperature, conductivity, tds, ph, waterLevel):
		self.temperature = temperature
		self.conductivity = conductivity
		self.ph = ph
		self.tds=tds
		self.waterLevel = waterLevel
		self.canvas = canvas
		self.feedingTime = 0
		self.feedingDay = 0
		self.updateAll = 30
		self.message = time.ctime()


	def display_data(self):
		bg = PhotoImage(file="image.png")
		self.board = canvas.create_image(0,0,image=bg, anchor="nw")
		self.canvas.create_text(300, 50,  text=self.message, font = ("Times", 36, "bold italic"), fill="#006994")
		self.canvas.create_text(300, 100, text="Temperature " + "{:.2f}".format(self.temperature) + " C", font = ("Times", 36, "bold italic"), fill="white")
		self.canvas.create_text(300, 150, text="Conductivity " + "{:.2f}".format(self.conductivity) + " uS", font = ("Times", 36, "bold italic"), fill="white")
		self.canvas.create_text(300, 200, text="TDS " + "{:.2f}".format(self.tds) + " ppm",font = ("Times", 36, "bold italic"), fill="white")
		self.canvas.create_text(300, 250, text="pH " + "{:.2f}".format(self.ph), font = ("Times", 36, "bold italic"), fill="white")
		self.canvas.create_text(300, 300, text="Water Level " + str(self.waterLevel), font = ("Times", 36, "bold italic"), fill="white")
		self.canvas.update()


	def update_board(self):

		if (self.updateAll >= 30):
			self.message = "Fetching Data..."
			self.display_data()
			self.temperature = self.getTemperature()
			self.conductivity = self.getConductivity()
			self.tds=self.conductivity/1000 * 700
			self.ph = self.getpH()
			self.waterLevel = self.getWaterLevel()
			self.updateAll = 0
		else:
			self.message = time.ctime()
		
		self.display_data()

		time.sleep(1)
		self.updateAll += 1
		self.feedingTime += 1
		if (self.feedingTime  >= 8640):
			self.feedingTime = 0
			self.feedFish()
		self.canvas.after(0, self.update_board)


	def feedFish(self):
		self.feedingDay += 1
		if (self.feedingDay > 7):
			self.feedingDay = 1

	def getTemperature(self):
		bus.write_byte(SENSOR_ADDRESS,4)
		time.sleep(1);
		Res=bus.read_byte(SENSOR_ADDRESS)
		R=10000*(1023/Res-1)
		logR=math.log(R)
		T=(1.0/(c1+c2*logR+c3*logR*logR*logR))
		T=T-273.5
		time.sleep(1)
		return T
		

	def getConductivity(self):
		bus.write_byte(SENSOR_ADDRESS,0)
		time.sleep(1);
		Res=bus.read_byte(SENSOR_ADDRESS)
		rawEC= 1000*Res/RES2/ECREF
		kValue=kHigh
		value=rawEC*kValue
		if (value<2.5):
			kValue=kLow
		value=rawEC*kValue
		value=value/(1.0+0.0185*(self.temperature-25))
		return value

	def getpH(self):
		bus.write_byte(SENSOR_ADDRESS,2)
		time.sleep(1)
		R=bus.read_byte(SENSOR_ADDRESS)
		time.sleep(1)
		slope=(7.0-4.0)/((pHNeutral-1500.0)/3.0-(pHAcid-1500)/3.0)
		intercept = 7.0-slope*(pHNeutral-1500.0)/3.0
		pH=slope*(R-1500.0)/3.0+intercept+5
		return pH

	def getWaterLevel(self):
		bus.write_byte(SENSOR_ADDRESS,3)
		time.sleep(1)
		R=bus.read_byte(SENSOR_ADDRESS)
		time.sleep(1)
		if (R>120):
			return "Good"
		else:
			return "LOW"

# initialize root Window and canvas
root = Tk()
root.title("Fish HUB")
root.geometry('600x400')
root.resizable(False,False)

canvas = Canvas(root, width = 600, height = 400)
canvas.pack()

# create the board  and update it
board = Board(canvas, 0, 0, 0, 0, 0)
board.update_board()

root.mainloop()






